==> newland-toubiz-api-2.7.5-70a431.zip: Classes/Service/Toubiz/ApiV1/EventService.php <==
<?php declare(strict_types=1);


namespace Newland\Toubiz\Api\Service\Toubiz\ApiV1;

use GuzzleHttp\Promise\EachPromise;
use GuzzleHttp\Psr7\Uri;
use Newland\Toubiz\Api\Service\AbstractService;
use Newland\Toubiz\Api\Service\LanguageAware;
use Newland\Toubiz\Api\Service\ServiceResult;
use Newland\Toubiz\Api\Service\Toubiz\ApiV1\ObjectAdapter\ArticleAdapter;
use Newland\Toubiz\Api\Service\Toubiz\ApiV1\ObjectAdapter\EventAdapter;

class EventService extends AbstractService
{
    use LanguageAware;
    const DEFAULT_BASE_URI = 'https://mein.toubiz.de';

    public function fetchEvents(callable $block): ServiceResult
    {
        $ids = $this->listAllIds();
        $total = count($ids);

        $pool = new EachPromise($this->requestDetailPages($ids), [
            'concurrency' => $this->parameters['concurrency'] ?? 10,
            'fulfilled' => function ($data) use ($block, $total) {
                $block(new EventAdapter($data), $total);
            }
        ]);

        $pool->promise()->wait();

        $result = new ServiceResult();
        $result->setAll($ids);
        return $result;
    }

    private function listAllIds(): array
    {
        $query = array_replace_recursive($this->parameters['request'] ?? [], [
            'api_token' => $this->apiKey,
            'minimal' => true,
            'language' => $this->language,
        ]);

        if ($this->delta !== null && $this->delta->asYears() < 1) {
            $query['filter'] = $query['filter'] ?? [];
            $query['filter']['updatedAfter'] = (new \DateTime())->sub($this->delta)->format('Y-m-d\TH:i:s');
        }

        $uri = (new Uri('api/v1/event'))->withQuery(http_build_query($query));

        return $this->jsonRequest($uri, 5, function (array $data) {
            return empty($data['_errors']);
        })->then(function (array $data) {
            return array_keys($data['payload']);
        })->wait();
    }

    private function requestDetailPages(array $ids): \Generator
    {
        $query = [
            'language' => $this->language,
            'api_token' => $this->apiKey,
            'include' => [
                'awards',
                'category',
                'client',
                'contactInformation',
                'dates',
                'externalIds',
                'fieldBlueprints',
                'fieldValues',
                'files',
                'location',
                'media',
                'price',
                'printInformation',
                'relatedArticles',
                'seo',
                'tags',
            ],
            'sizes' => [
                'preview' => $this->parameters['previewSize'] ?? '600'
            ]
        ];

        foreach ($ids as $id) {
            $uri = (new Uri(sprintf('api/v1/event/%s', $id)))->withQuery(http_build_query($query));
            yield $this->jsonRequest($uri, 5, function ($data) {
                return empty($data['_errors']);
            })->then(function ($data) {
                return $data['payload'];
            });
        }
    }
}

==> newland-toubiz-api-2.18.16-2a9278.zip: Classes/Service/Toubiz/ApiV1/EventService.php <==
<?php declare(strict_types=1);


namespace Newland\Toubiz\Api\Service\Toubiz\ApiV1;

use GuzzleHttp\Promise\EachPromise;
use GuzzleHttp\Psr7\Uri;
use Newland\Toubiz\Api\Service\AbstractService;
use Newland\Toubiz\Api\Service\LanguageAware;
use Newland\Toubiz\Api\Service\ServiceResult;
use Newland\Toubiz\Api\Service\Toubiz\ApiV1\ObjectAdapter\EventAdapter;

class EventService extends AbstractService
{
    use LanguageAware;

    const DEFAULT_BASE_URI = 'https://mein.toubiz.de';

    /** @var string[] */
    private $detailUriTemplates = [];

    public function setDetailUriTemplates(array $detailUriTemplates): void
    {
        $this->detailUriTemplates = $detailUriTemplates;
    }

    public function fetchEvents(callable $block): ServiceResult
    {
        $ids = $this->listAllIds();
        $total = count($ids);

        $pool = new EachPromise($this->requestDetailPages($ids), [
            'concurrency' => $this->parameters['concurrency'] ?? 10,
            'fulfilled' => function ($data) use ($block, $total) {
                $eventAdapter = $this->bodyToAdapter($data);
                $block($eventAdapter, $total);
            },
        ]);

        $pool->promise()->wait();

        $result = new ServiceResult();
        $result->setAll($ids);
        return $result;
    }

    public function fetchEvent(string $id, callable $block): ServiceResult
    {
        $ids = [ $id ];

        $pool = new EachPromise($this->requestDetailPages($ids), [
            'concurrency' => $this->parameters['concurrency'] ?? 10,
            'fulfilled' => function ($data) use ($block) {
                $eventAdapter = $this->bodyToAdapter($data);
                $block($eventAdapter);
            },
        ]);

        $pool->promise()->wait();

        $result = new ServiceResult();
        $result->setAll($ids);
        return $result;
    }

    private function bodyToAdapter(?array $body): ?EventAdapter
    {
        if ($body === null) {
            return null;
        }

        $eventAdapter = new EventAdapter($body);
        $eventAdapter->setDetailUriTemplates($this->detailUriTemplates);

        return $eventAdapter;
    }

    private function listAllIds(): array
    {
        $query = array_replace_recursive($this->parameters['request'] ?? [], [
            'api_token' => $this->apiKey,
            'minimal' => true,
            'language' => $this->language,
        ]);

        if ($this->delta !== null && $this->delta->asYears() < 1) {
            $query['filter'] = $query['filter'] ?? [];
            $query['filter']['updatedAfter'] = (new \DateTime())->sub($this->delta)->format('Y-m-d\TH:i:s');
        }

        $uri = (new Uri('api/v1/event'))->withQuery(http_build_query($query));

        return $this->jsonRequest($uri, 5, function (array $data) {
            return empty($data['_errors']);
        })->then(function (array $data) {
            return array_keys($data['payload']);
        })->wait();
    }

    private function requestDetailPages(array $ids): \Generator
    {
        $query = [
            'language' => $this->language,
            'api_token' => $this->apiKey,
            'include' => [
                'awards',
                'channelContext',
                'client',
                'contactInformation',
                'dates',
                'externalIds',
                'fieldBlueprints',
                'fieldValues',
                'files',
                'location',
                'media',
                'partners',
                'price',
                'printInformation',
                'relatedArticles',
                'seo',
                'tags',
            ],
            'sizes' => [
                'preview' => $this->parameters['previewSize'] ?? '600',
            ],
        ];

        foreach ($ids as $id) {
            $uri = (new Uri(sprintf('api/v1/event/%s', $id)))->withQuery(http_build_query($query));
            yield $this->jsonRequest($uri, 5, function ($data) {
                return empty($data['_errors']);
            })->then(function ($data) {
                return $data['payload'];
            });
        }
    }
}
